@@ -41,16 +41,16 @@
 LoggerDialog::LoggerDialog(TQWidget *parent, const char *name) :
 	LoggerDialogBase(parent, name) {
 		
-	connect(buttonOK, TQT_SIGNAL(clicked()), this, TQT_SLOT(sendMessage()));
+	connect(buttonOK, TQ_SIGNAL(clicked()), this, TQ_SLOT(sendMessage()));
 	
-	connect(tagActivation, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(tagActivationChanged(bool)));
-	connect(fileActivation, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(fileActivationChanged(bool)));
-	connect(messageActivation, TQT_SIGNAL(toggled(bool)), this, TQT_SLOT(messageActivationChanged(bool)));
+	connect(tagActivation, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(tagActivationChanged(bool)));
+	connect(fileActivation, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(fileActivationChanged(bool)));
+	connect(messageActivation, TQ_SIGNAL(toggled(bool)), this, TQ_SLOT(messageActivationChanged(bool)));
 	
 	
-	connect(file, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(textChanged(const TQString&)));
-	connect(message, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(textChanged(const TQString&)));
-	connect(tag, TQT_SIGNAL(textChanged(const TQString&)), this, TQT_SLOT(textChanged(const TQString&)));
+	connect(file, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(textChanged(const TQString&)));
+	connect(message, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(textChanged(const TQString&)));
+	connect(tag, TQ_SIGNAL(textChanged(const TQString&)), this, TQ_SLOT(textChanged(const TQString&)));
 
 	buildMaps();
 	
