@@ -36,7 +36,7 @@ Reader::Reader(TQObject *parent, const char *name) :
 	
 	watch=new KDirWatch();
 	kdDebug() << watch->internalMethod() << endl;
-	connect(watch, TQT_SIGNAL(dirty(const TQString&)), this, TQT_SLOT(logChanged(const TQString&)));
+	connect(watch, TQ_SIGNAL(dirty(const TQString&)), this, TQ_SLOT(logChanged(const TQString&)));
 }
 
 Reader::~Reader() {
