@@ -64,7 +64,7 @@ class ViewToolTip;
  */
 class View : public TQWidget, public KSystemLogInterface {
 	
-	Q_OBJECT
+	TQ_OBJECT
   
 
 	public:
