@@ -39,7 +39,7 @@
  * @author Nicolas Ternisien
  */
 class XorgReader : public DefaultReader {
-	Q_OBJECT
+	TQ_OBJECT
   
 	
 	public:
